module.exports = {
  root: true,
  plugins: [ 'prettier' ],
  extends: [ '@webpack-contrib/eslint-config-webpack' ],
  rules: {
    'prettier/prettier': [
      'error',
      { singleQuote: true, trailingComma: 'es5', arrowParens: 'always' }
    ]
  }
};
